<?php
/*
*   class HTools, tools for MyHistoricalNews
*		V-1-7-7-2
*	André DUMAS FRANCE
*		22-08-2016
*		V-1-7-9-1   01 MAY 2017
*		V-1-7-9-2   21 JAN 2018
* 	see on http://www.adumas.1s.fr/wt ->favorite
*/
namespace Andre\WebtreesAddOn\Histo;

use Composer\Autoload\ClassLoader;
use Fisharebest\Webtrees\Controller\BaseController;
use Fisharebest\Webtrees\Controller\PageController;
use Fisharebest\Webtrees\Filter;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Log;
use Fisharebest\Webtrees\Individual;
use Fisharebest\Webtrees\Menu;
use Fisharebest\Webtrees\Media;
use Fisharebest\Webtrees\Auth;
use Fisharebest\Webtrees\Site;
use Fisharebest\Webtrees\Fact;
use Fisharebest\Webtrees\Date;
use Fisharebest\Webtrees\Tree;
use Fisharebest\Webtrees\Stats;
use Fisharebest\Webtrees\Database;
use Fisharebest\Webtrees\Functions;
use Fisharebest\Webtrees\Functions\FunctionsEdit;
use Fisharebest\Webtrees\Functions\FunctionsPrint;
use finfo;

use Andre\WebtreesAddOn\Histo\classMediaUpload;


class HTools extends histoModule {

	/**
	 * Get any historical events from histo.xx.php.
	 *
	 * @param Individual $person
	 *
	 * @return Fact[]
	 */
	protected static function historicalFacts(Individual $person) {
		$SHOW_RELATIVES_EVENTS = true;
		$facts = array();
	
			if ($SHOW_RELATIVES_EVENTS) {
				// Only include events between birth and death
				$birt_date = $person->getEstimatedBirthDate();
				$deat_date = $person->getEstimatedDeathDate();
				
		if ( ($birt_date->maximumDate()->y) || ($deat_date->maximumDate()->y) ){ 
					
				if (file_exists(Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php')) {
					$histo = array();
					require Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php';
					foreach ($histo as $hist) {
						// Earlier versions of the WIKI encouraged people to use HTML entities,
						// rather than UTF8 encoding.
						$hist = html_entity_decode($hist, ENT_QUOTES, 'UTF-8');

						$fact  = new Fact($hist, $person, 'histo');
						$sdate = $fact->getDate();
						if (($sdate->isOK() && Date::compare($birt_date, $sdate) <= 0 && Date::compare($sdate, $deat_date) <= 0) && ( $fact->getFactId() == 'histo')){
							$facts[] = $fact;
						}
					}
				}
			}
		}	
		return $facts;
	}
/*
*	read histo.xx.php  file
*	return  array $histo
*/
public function readHistoFile(){
	
	$this->hists = array();
		if (file_exists(Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php')) {				
				$events = array();
				require Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php';
				
				foreach ($histo as $hist) {
					// Earlier versions of the WIKI encouraged people to use HTML entities,
					// rather than UTF8 encoding.
					$hist = html_entity_decode($hist, ENT_QUOTES, 'UTF-8');
				} 
				
			$this->hists = $histo;	$hist = $histo;
		} else {
			$this->hists = null;
			return false;
		}	
		
	return $histo;	
}
	

	/**
	 * Get the value of level 2 data in the fact
	 *
	 * @param string $tag
	 *
	 * @return array|null
	 
	 * array(2) {[0]=> array(x : nbre occurence, str complete  [1] =>array(x nbre occurences : contenu de la NOTE (Tag)}
	 */
	private function getAttributes($tag, $gedcom) {
		$tagsValue = array();
		if (preg_match_all('/\n2 '. $tag . ' (.+)/', $gedcom, $match)) {
			foreach ($match[1] as $item){
				$tagsValue[] = $item;
			}
			return $tagsValue;
		} else {
			return null;
		}
	}
	
	protected function getHistoDate($histo){
		return $this->getAttributes('DATE', $histo)[0];
	}
	
	protected function getHistoType($histo){
		return $this->getAttributes('TYPE', $histo)[0];
	}
	
	protected function getHistoTitle($histo){
		return $this->getAttributes('NOTE', $histo)[0];
	}
	
	/*
	*  return an array() of notes
	*/
	protected function getHistoNotes($histo){
		return $this->getAttributes('NOTE', $histo);
	}
	
	protected function getHNotes($histo){
		$notes = array();
		$tmp = explode('2 NOTE ', str_replace('\n', "\n", $histo));
		$no_note = array_shift($tmp);
		return $tmp;
	}
	
	protected function getHistoMedia($histo){
		$media = $this->getAttributes('NOTE', $histo);
		if (count($media) > 1){
			return $media[count($media) - 1];
		} else {
			return false;
		}
	}
	
	/*
	*	param hEvent = $this->hists[]
	*	one raw of the histo file histo[]
	*/
	public  function editHistoFact($hEvent, $hindex = -1){
		$notes = $this->getHNotes($hEvent);
	
		$hEvent = str_replace('\n', "\n", $hEvent);
		/*************************
	
		/*
			edit Fact -><form>
			
				add a note for this media with the name of a picture (filename: yyy.xxx)
		*/
//		$tmpnotes = $this->getAttributes('NOTE', $hEvent);
		$tab = explode("\n" . ' NOTE ', $hEvent);
		
		$c_notes = count($notes);
		/*
		$c_notes = 	1 	version orig sans photo
					2	version 1 avec pg_version
					6 	version current with comment link photo
		*/
		switch ($c_notes){ // this is only for compatibility with  previous version
			case '1': //original webtrees
				$notes = array($notes[0], '', '', $this->getSetting('JOURNAL_DEFAULT_CTY'), '', '');
			break;
			case '2': //first version with image
				$notes = array($notes[0], '', '', $this->getSetting('JOURNAL_DEFAULT_CTY'), '', $notes[1]);
			break;
			default:
				///dim =6 normal
				$notes = $notes;
			break;
		}
		$c_notes = count($notes); //6
		if (strlen($notes[3]) < 3 ){ $notes[3] = $this->getSetting('JOURNAL_DEFAULT_CTY');}
	
		/* help text */
		$htype =I18N::translate('Event, President of France, scientific event, ... 254 chars max ');
		$hdate =I18N::translate('Enter the date with any format: jj-dd-yyyy j/d/y ...');
		$hnote =I18N::translate('Name of the President, short description of the event  64 chars max');
		$comment_note =I18N::translate('Comment / description of the event  254 chars max');
		$fcty =I18N::translate('Country of the event  254 chars max');
		$link_ev_note =I18N::translate('A link for this event  254 chars max');
		$link_img_note =I18N::translate('A link for this image  254 chars max');
		$hmedia =I18N::translate('Name of the media without any path. YOU must downoad, copy, FTP the picture in data/journal/thumbs Height max 60 px');
		/*  */
		$form = '';
		$titre = '<p class="evtitle">' . I18N::translate('Historical event') . '</p>';
		
		$form = '<form name="ffact" id="ffact" enctype="multipart/form-data" method="POST" 
				action="module.php?mod='. $this->getName() . '&mod_action=admin_config"  >' .
		
				'<div id="ffacts">' .
				Filter::getCsrf() . '
					<input type="hidden" name="save" value="' . true . '">
					<input type="hidden" name="idrecord" id="idrecord" value="' . $hindex . '">
					<input type="hidden" name="submission" id="submission" value="1">
					<table id="tablefact">
					<tr>
					<th colspan="2">' . $titre . '</th></tr>' .
					'<tr>
							<td>
							<span>' . I18N::translate('TYPE').'*</span><span class="icon-help" title="' . $htype . '"></span>
							</td>
							<td>' .
									$this->selectTypeOfEvent()
								. '<input type="text"  name="ftype" id="ftype" rows="1" style="width:100%;" value="' . $this->getAttributes('TYPE', $hEvent)[0] . '"/>
								<p></p>
								<fieldset>
								<label><input type ="checkbox" id=default_flag" name="default_flag" 
								title="' . I18N::translate('Click to set this country as the default country for national events') . '"
								/>' . I18N::translate(' Set this country as the default country') . '</label>
								<p id="jflags">' . $this->selectCountryFlag() . '</p>
								</fieldset>
							</td>
						</tr>
						<tr>
							<td>
							<span>' . I18N::translate('DATE').'*</span><span class="icon-help" title="' . $hdate . '"></span>
							</td>
							<td>
								<input type="text" name="fdate" style="width:80%;" id="fdate" value="' . $this->getAttributes('DATE', $hEvent)[0]  . '" 
									onblur="valid_date(this);" onmouseout="valid_date(this);" 
									>
								<a href="#" onclick="cal_toggleDate(\'caldivsndate\', \'fdate\'); return false;"
									class="icon-button_calendar" title="' . I18N::translate('Choose a date'). '">
								</a>
							</td>
						</tr>
						<tr>
							<td>
							<span>' . I18N::translate('NAME').'*</span><span class="icon-help" title="' . $hnote . '"></span>
							</td>
							<td>
								<input name="fnote" id="fnote" maxlength="64" rows="1" style="width:100%;" 
										value="' . $notes[0] . '"/>
							</td>
						</tr>
						
						<tr>
							<td>
							<span>' . I18N::translate('COUNTRY').'</span><span class="icon-help" title="' . $fcty . '"></span>
							</td>
							<td>
								<input type="text" name="icty" id="icty" style="width:100%;" value="' . explode(' ', ($notes[3]))[1] . '" readonly />
							</td>
						</tr>
						
						<tr>
							<td>
							<span>' . I18N::translate('LINK EVENT').'</span><span class="icon-help" title="' . $link_ev_note . '"></span>
							</td>
							<td>
								<input type="url" name="link_ev_note" id="link_ev_note" rows="1" style="width:100%;" maxlength="254" value="' . ($notes[2]) . '"/>
							</td>
						</tr>
						
						<tr>
							<td>
							<span>' . I18N::translate('COMMENT').'</span><span class="icon-help" title="' . $comment_note . '"></span>
							</td>
							<td>
								<textarea name="comment_note" id="comment_note" rows="4" maxlength="254" style="width:100%;">' . ($notes[1]) . '</textarea>
							</td>
						</tr>
						
						<tr><td colspan="2">'.
							 classMediaUpload::printFormUpload() . '
							</td>
						</tr>
						<tr>
						<td title="' .
							I18N::translate('Do not change to keep original filename.') . '" >' .
							I18N::translate('Change filename on server') .
						'</td>
						<td><input id="ifilename"
							name="filename" type="text" size="50" value="' . ($notes[$c_notes - 1]) . '" 	
							title="' . 
							I18N::translate('Do not change to keep original filename.') . '</p>
							<p> ' . 
								I18N::translate('The media file you are uploading can be, and probably should be, named differently on the server than it is on your local computer. This is so because often the local filename has meaning to you but is much less meaningful to others visiting this website. Consider also the possibility that you and someone else both try to upload different files called “granny.jpg“.<br><br>In this field, you specify the new name of the file you are uploading. The name you enter here will also be used to name the thumbnail, which can be uploaded separately or generated automatically. You do not need to enter the filename extension (jpg, gif, pdf, doc, etc.)<br><br>Leave this field blank to keep the original name of the file you have uploaded from your local computer.') . 
							'</p> 
							" readonly >
						</td>
						</tr>
						<tr>
							<td>
							<span>' . I18N::translate('LINK IMAGE').'</span><span class="icon-help" title="' . $link_img_note . '"></span>
							</td>
							<td>
								<input type="url" name="link_img_note" id="link_img_note" maxlength="254" rows="2" style="width:100%;" value="' . ($notes[4]) . '"/>
							</td>
						</tr>
												
						<tr>
						<th colspan="1">' . 							
						'</th>
						<th colspan="1">' . 
							'<button id="fsubmit" class="btn btn-primary" type="submit" 
							title="' . I18N::translate('DATE cannot be empty') . '">						
							<i class="fa fa-check"></i>' .
								I18N::translate('save') .
							'</button>' .
						'</th>
						</tr>
					</table></div></form>';	
				
		return $form;
	}
	
	/*
	
	*
	*
	*/
	private function selectCountryFlag(){
		global $WT_TREE;
		$stats = new Stats($WT_TREE);
		$countries = $stats->getAllCountries();
		natsort($countries);
		$html = '<select id="fcty" name="fcty">
					<option value="0">' . I18N::translate('Choose the country') . '</option>';
			foreach ($countries as $ckey => $cname){
				$html .= '<option value="' .  $ckey . ' ' . $cname . '">' . $cname . '</option>';				
			}	
		$html .= '</select>';
		
	return $html;	
	}

	
	/*
	*	find the position of the new row in tab histo
	*   depnds only on the date
	*/
	/*
	*   param  $ndate date og the new EVEN from <form> -> conf page
	*	param   $nrow new data from <form> conf page
	* 	param   $tab = content of histo.xx.php 
	*/
		public function insertNewHistoRow($ndate, $nrow){
			
		$tab = $this->readHistoFile();	
		$tmp1 = array();
		
		$ondate = new Date($ndate);
		$ohdate = new Date($this->getHistoDate($tab[2]));
		
		$dim = count($tab) - 1;
		$hdim = (int)($dim/2); //milieu du tableau
		
		$data = $nrow;
				
		if ( Date::compare($ondate, new Date($this->getHistoDate($tab[0]) )) < 0 ){
			$tmp1[] = $data;
			$tmp1 = array_merge($tmp1, $tab);
			$this->createHistoFile($tmp1);
			return true;
		}
		
		if (Date::compare($ondate, new Date($this->getHistoDate($tab[$dim]))) > 0){
			$tmp1 = $tab;
			$tmp1[] = $data;
			$this->createHistoFile($tmp1);
			return true;
		}
	
		$hdim = (int)($dim/2);
		$idx_inf = 0;
		$idx_sup = $dim;
		$delta = $hdim;		
		$index = $delta;

		while ($delta != 0){	
			$diff = Date::compare($ondate, new Date($this->getHistoDate($tab[$index])));
			if ($diff > 0) {
				$idx_inf = $idx_inf + $delta;
			} else {
				$idx_sup = $idx_sup - $delta;
			}
			$delta = (int)($delta/2);
			$index = (int)( ($idx_sup + $idx_inf)/2 );
			$ccdate = new Date($this->getHistoDate($tab[$index]));
		}

	// on affine $index
	if ((($index -3) < 0)){$index = 0;} else {$index = $index - 3;} 
	
	$diff = $diff = Date::compare($ondate, new Date($this->getHistoDate($tab[$index])));
	while ($diff > 0){
		$index = $index + 1;
		$diff = Date::compare($ondate, new Date($this->getHistoDate($tab[$index])));
	}

		/* update tab*/
		$tmp1 = $tab;
		$j = 1;

		$tmp1[$index] = $data;
		for ($i = $index; $i <= $dim; $i++){
			$tmp1[$index + $j] = $tab[$i];
			$j++;
		}
		/* Create histo file */	
		$this->createHistoFile($tmp1);
	}
	
	/*
	* 	Call from config() submit
	*  	just call function
	*/
	public function modifyExistingHistoRow($tab){
		return $this->createHistoFile($tab);
	}

	/**
	*
	*   à virer
	*/
	protected function updateHistoRecord($gedcomhisto, $hindex){
		
				$this->readHistoFile();

		
		 $tab[$hindex] = $gedcomhisto; 
		$this->createHistoFile($tab);		
	}
	
	/*
	*   create histo.xx.php updated
	*/
	private function createHistoFile($tab){ 	
		$header = '<?php
/* *
 * File used to display EVENrical facts on individual page
 *
 * Each line is a GEDCOM style record to describe an EVENt, including newline chars (\n)
 * File included in : person_class.php
 *
 * $Id: EVEN.fr.php p_14 $
  * Fichier utilisé pour afficher des faits EVENrical à la page individuelle
  *=====================================================================================================
  * Chaque ligne est un enregistrement GEDCOM style pour décrire un événement, y compris les caractères de nouvelle ligne (\ n)
  * Fichier inclus dans: person_class.php
  *
  * $ Id: EVEN.fr.php p_14 $
  TypeError: $(...).value is undefined[En savoir plus] admin.js:164:8

  */
if (stristr($_SERVER["SCRIPT_NAME"], basename(__FILE__))!==false) {
	print "You cannot access this file directly.";
	exit;
}


		';
		
	$footer = '?>';

	$text = $header . PHP_EOL;
	
	for ($i = 0; $i < count($tab); $i++){
		$l = str_replace("\n", '\n', $tab[$i]);
		$text .= '$histo[] = "' . $l . '";' . PHP_EOL; 
		
	}
	$text .= $footer;
	
	$file = WT_DATA_DIR . 'histo.' . WT_LOCALE . '.php';
	$handle = fopen($file, 'w+');
	fwrite($handle, $text);
	fclose($handle);
	
	return true;	
		
	}
	
	
	/*
	*	insert a row in a table
	*    param $tab  
	*	$valeur Insert new row
	*   $indice  position
	*/
	
	private function insert_i($tab,$valeurInsert,$indice){
		$nouveauTab = array();
    foreach($tab as $cle=>$valeur)
    {
       if ($cle == $indice)
            array_push($nouveauTab,$valeurInsert);
 
       array_push($nouveauTab,$valeur);
    }
 
   return $nouveauTab;
}
	
		
	/**
	 * Extract HISTO structure from the incoming histo record
	 * The output array is defined as follows:
	 *  $textSOUR['PAGE'] = Source citation
	 *  $textSOUR['EVEN'] = Event type
	 *  $textSOUR['ROLE'] = Role in event
	 *  $textSOUR['DATA'] = place holder (no text in this sub-record)
	 *  $textSOUR['DATE'] = Entry recording date
	 *  $textSOUR['TEXT'] = (array) Text from source
	 *  $textSOUR['QUAY'] = Certainty assessment
	 *
	 * @param string $srec
	 *
	 * @return string[tag]
	 *   
	 *
	 *  see Functions::printFacts->printSourceStructure
	 */
	public static function getHistoStructure($hrecord) {
		// Set up the output array
		$textHISTO = array(
			'EVEN' => '',
			'DATE' => '',
			'NOTE' => array(),
			);
		if ($hrecord) {
			$subrecords = explode("\n", $hrecord);
			for ($i = 0; $i < count($subrecords); $i++) {
				$tag  = substr($subrecords[$i], 2, 4);
				$text = substr($subrecords[$i], 7);
				$i++;
				for (; $i < count($subrecords); $i++) {
					$nextTag = substr($subrecords[$i], 2, 4);
					if ($nextTag != 'CONT') {
						$i--;
						break;
					}
					if ($nextTag == 'CONT') {
						$text .= "\n";
					}
					$text .= rtrim(substr($subrecords[$i], 7));
				}
				if ($tag == 'NOTE') {
					$textHISTO[$tag][] = $text;
				} else {
					$textHISTO[$tag] = $text;
				}
			}
		}

		return $textHISTO;
	}

	/*
	*   get value of a tag from histo structure
	*
	*/
		protected function getValue($tag, array $histo) {
			
		return Filter::escapeHtm($histo[$tag]);	
		}
		
	
	/*
	*	get mimeType
	*  	param $file file name
	*/
	protected function MimeType($file){
		$filename = WT_DATA_DIR . $this->getName() .'/thumbs/' . $file;		
		$finfo = finfo_open(FILEINFO_MIME_TYPE); // Retourne le type mime à l'extension mimetype
		$mtype = finfo_file($finfo, $filename) ;
		finfo_close($finfo);
	return $mtype;
	}
	
	/*
	*
	*/
	public static function getExtFile($file){
		$ext = (explode('.', $file)); 
		return  end($ext);
	}
	
	/**
	 * What is the mime-type of this object?
	 * For simplicity and efficiency, use the extension, rather than the contents.
	 *
	 * @return string
	 */
	public static function getMimeType($file) {
		// Themes contain icon definitions for some/all of these mime-types
		switch (self::getExtFile($file)) {
		case 'bmp':
			return 'image/bmp';
		case 'doc':
			return 'application/msword';
		case 'docx':
			return 'application/msword';
		case 'ged':
			return 'text/x-gedcom';
		case 'gif':
			return 'image/gif';
		case 'htm':
			return 'text/html';
		case 'html':
			return 'text/html';
		case 'jpeg':
			return 'image/jpeg';
		case 'jpg':
			return 'image/jpeg';
		case 'mov':
			return 'video/quicktime';
		case 'mp3':
			return 'audio/mpeg';
		case 'ogv':
			return 'video/ogg';
		case 'pdf':
			return 'application/pdf';
		case 'png':
			return 'image/png';
		case 'rar':
			return 'application/x-rar-compressed';
		case 'swf':
			return 'application/x-shockwave-flash';
		case 'svg':
			return 'image/svg';
		case 'tif':
			return 'image/tiff';
		case 'tiff':
			return 'image/tiff';
		case 'xls':
			return 'application/vnd-ms-excel';
		case 'xlsx':
			return 'application/vnd-ms-excel';
		case 'wmv':
			return 'video/x-ms-wmv';
		case 'zip':
			return 'application/zip';
		default:
			return 'application/octet-stream';
		}
	}

	
	/*
	*   Read file histo and create an array of object fact 
	*   return $this->facts
	*/
	public function readHistoFacts(){
	
		if ($this->facts == null){
			//open histo file
			if (file_exists(Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php')) {
				$histo = array();
				require Site::getPreference('INDEX_DIRECTORY') . 'histo.' . WT_LOCALE . '.php';

					foreach ($histo as $hist) {
						// Earlier versions of the WIKI encouraged people to use HTML entities,
						// rather than UTF8 encoding.
						$hist = html_entity_decode($hist, ENT_QUOTES, 'UTF-8');

						$fact  = new Fact($hist, $person, 'histo');
							$this->facts[] = $fact;
					}
			}
		}
	return true;			
	}
	
	/*
	*
	*/
	
	public function selectListHistoFacts($tab){
		
		$html = '<select id="selectHEvent" 
						title="' . I18N::translate('Don\'t choose to enter a new event. If you choose one you will edit it only')   . '">';
		if (!null == $tab){
			$html .= '<option value="-1">' . I18N::translate('Choose a fact or event and edit it below') . '</option>';			
				for ($i = 0; $i <= count($tab) - 1;$i++){
					$html .= '<option value="' . $i . '">' . $i .': ' .$tab[$i] . '</option>';
				}
		} else {
			$html .= '<option value="-1">' . I18N::translate('histo file does not exist') . '</option>';			
		}
		$html .= '</select>';
	return $html;	
	}
	
	
	
	/**
 * Supprimer les accents
 * 
 * @param string $str chaîne de caractères avec caractères accentués
 * @param string $encoding encodage du texte (exemple : utf-8, ISO-8859-1 ...)
 */
	public static function delAccents($str, $encoding='utf-8'){	
	
    // transformer les caractères accentués en entités HTML
    $str = htmlentities($str, ENT_NOQUOTES, $encoding);
 
    // remplacer les entités HTML pour avoir juste le premier caractères non accentués
    // Exemple : "&ecute;" => "e", "&Ecute;" => "E", "Ã " => "a" ...
    $str = preg_replace('#&([A-za-z])(?:acute|grave|cedil|circ|orn|ring|slash|th|tilde|uml);#', '\1', $str);
 
    // Remplacer les ligatures tel que : Œ, Æ ...
    // Exemple "Å“" => "oe"
    $str = preg_replace('#&([A-za-z]{2})(?:lig);#', '\1', $str);
    // Supprimer tout le reste
    $str = preg_replace('#&[^;]+;#', '', $str);
 
    return $str; 
	}
	
	/*
	*  cache 
	*/
	public function myDir() {
		return WT_DATA_DIR . $this->getName() . '/';
	}
	
	
		/**
	 * Print the  thumbnail for this historical fact
	 *
	 * @param $file
	 * @return thumbnail
	 */
	protected function printThumbnail($file, $link = '') {
		
		//$link = '';
		$link1 = '';
		
			$filename = $this->myDir() . 'thumbs/' . $file;	
			$mimetype = $this->getMimeType($file);
			if (is_file($filename)) {
				$imgsize = getimagesize($filename);
				$image	 = '<img' .
					' dir="' . 'auto' . '"' . // For the tool-tip
					' src="module.php?mod=' . $this->getName() . '&amp;mod_action=thumbnail&amp;file=' . $file . '&amp;thumb=2&amp;cb=' . trim(md5_file($filename), '"\'') . '"' .
					' alt="' . ' ' . '"' .
					' title="' . $file . '"' .
					' data-cachefilename="' . basename($filename) . '"' .
					' ' . $imgsize[3] . // height="yyy" width="xxx"
					'>';
				
					$html = '<a' .
					' class="' . '' . '"' .
					' href="' . $link . '"' .
					' type="' . $mimetype . '"' .
					' data-obje-url="' . $link1 . '"' .
					' data-obje-note="' . ' ' . '"' .
					' data-title="' . $file . '"' .
					'>' . $image . '</a>';
					
					return $html;
			} else {
				return '<a></a>';
			}
		
	}
	
	protected function printFlag($file, $link = '') {
		
		$link1 = '';
		
			$filename = WT_MODULES_DIR. $this->getName() . '/' . $file;	
			$mimetype = $this->getMimeType($file);
			
			if (is_file($filename)) {
				$imgsize = getimagesize($filename);
				$image	 = '<img' .
					' dir="' . 'auto' . '"' . // For the tool-tip
					' src="module.php?mod=' . $this->getName() . '&amp;mod_action=thumbnail&amp;file=' . $file . '&amp;thumb=2&amp;cb=' . trim(md5_file($filename), '"\'') . '"' .
					' alt="' . ' ' . '"' .
					' title="' . $file . '"' .
					' data-cachefilename="' . basename($filename) . '"' .
					' ' . $imgsize[3] . // height="yyy" width="xxx"
					'>';
				
					$html = '<a' .
					' class="' . '' . '"' .
					' href="' . $link . '"' .
					' type="' . $mimetype . '"' .
					' data-obje-url="' . $link1 . '"' .
					' data-obje-note="' . ' ' . '"' .
					' data-title="' . $file . '"' .
					'>' . $image . '</a>';
					
					return $html;
			} else {
				return '<a></a>';
			}
		
	}
	
	/*
	*	create a form to choose tha fact you want 
	*/
	private function chooseFact(){
		/* what century? */
		$century = array('I', 'II', 'III', 'IV', 'V', 'VI', 'VII', 'VIII', 'IX', 'X', 'XI', 'XII', 'XIII', 'XIV', 'XV', 'XVI', 'XVII', 'XVIII', 'XIX', 'XX', 'XXI');
		/* choose decade */
		$decade = array('0-10', '11-20', '21-30', '31-40', '41-50', '51-60', '61-70', '71-80', '81-90', '91-99');
		/*on change century we fill list of facts for this century*/
		
	return $fact;	
	}
	
	/*
	*    Select facts
	*	param $date dd-mm-yyyy
	*/
	private function selectFacts($date1, $date2){
		$facts = array();
		
	return facts;	
	}



	protected static function addHistoFact(){
		$gedrecord = '
			1 EVEN\n
			2 TYPE ' . $etype . '\n
			2 DATE ' . $edate . '\n
			2 NOTE ' . $enote . '\n
			2 OBJE ' . $eobject ;
		// or  associated with a SOUR
		
	}
	
	private function createJournal(){
		
	}
	
	private function sortHistoFacts(){
		
	}
	
	private function delHistoFact(){
		
	}
	
	/* Print the  image for this historical fact
	 *
	 * @param $file
	 * @param $dir
	 * @return $html image
	 */
	public function printImage($file, $dir, $link = '', $link1 = '') {
				
			$filename = $dir . '/' . $file; 
				
			$mimetype = $this->getMimeType($file);
			if (!file_exists($filename)  ){
				$file = self::DEFAULT_PICTURE;
				$filename = $dir . '/' . $file;
				$mimetype = $this->getMimeType($file);
			}
			
				$imgsize = getimagesize($filename);
				$image	 = '<img' .
					' dir="' . 'auto' . '"' . // For the tool-tip
					' src="module.php?mod=' . $this->getName() . '&amp;mod_action=thumbnail&amp;file=' . $file . '&amp;thumb=2&amp;cb=' . trim(md5_file($filename), '"\'') . '"' .
					' alt="' . ' ' . '"' .
					' title="' . $file . '"' .
					' data-cachefilename="' . basename($filename) . '"' .
					' ' . $imgsize[3] . // height="yyy" width="xxx"
					'>';
				
					$html = '<a' .
					' class="' . '' . '"' .
					' href="' . $link . '"' .
					' type="' . $mimetype . '"' .
					' data-obje-url="' . $link1 . '"' .
					' data-obje-note="' . ' ' . '"' .
					' data-title="' . $file . '"' .
					'>' . $image . '</a>';
					
					return $html;
		
	}
	
	private static function selectTypeOfEvent(){
		$html = '<select id="evtype" style="width:100%;">';
		    $html .= '<option value="0">' . I18N::translate('Choose a type of event or define a new one above') . '</option>';
			
			$html .= '<option value="1">' . I18N::translate('President') . '</option>';
			$html .= '<option value="2">' . I18N::translate('Queen') . '</option>';
			$html .= '<option value="3">' . I18N::translate('King') . '</option>';
			$html .= '<option value="4">' . I18N::translate('Empire') . '</option>';
			$html .= '<option value="5">' . I18N::translate('History of sciences') . '</option>';
			$html .= '<option value="6">' . I18N::translate('History of arts') . '</option>';
			$html .= '<option value="7">' . I18N::translate('National event/fact') . '</option>';
			$html .= '<option value="8">' . I18N::translate('International event/fact') . '</option>';
			
		$html .= '</select>'; 
		return $html;
	}
	
	

	
} 

?>