<?php
/*
 * webtrees: online genealogy
 * Copyright (C) 2015 webtrees development team
 * Copyright (C) 2015 JustCarmen
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
namespace Andre\WebtreesAddOn\Histo\Template;

use Fisharebest\Webtrees\Auth;
use Fisharebest\Webtrees\Controller\PageController;
use Fisharebest\Webtrees\Filter;
use Fisharebest\Webtrees\Site;
use Fisharebest\Webtrees\Stats;
use Fisharebest\Webtrees\Log;
use Fisharebest\Webtrees\Functions\FunctionsEdit;
use Fisharebest\Webtrees\Functions\FunctionsPrint;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Session;

use Andre\WebtreesAddOn\Histo\histoModule;
use Andre\WebtreesAddOn\Histo\HTools;
use Andre\WebtreesAddOn\Histo\classMediaUpload;
use Andre\WebtreesAddOn\Histo\myUpdateFunctions;


class AdminTemplate extends histoModule {

	protected function pageContent() {
		
		if (Filter::postBool('save')){
			$len = 254;
			$hsave = array(
				'hsave'    => true ,
				'htype'    => substr(Filter::post('ftype'), 0, $len),
				'hdate'    => Filter::post('fdate'),
				'hname'    => substr(Filter::post('fnote'), 0, $len),
				'hindex'   => Filter::post('idrecord'),
				'country'  => trim(Filter::post('icty')),
				'fdefault' => Filter::post('default_flag'), /*bool checkbox */
				'hcomment' => str_replace("\n", ' ', Filter::post('comment_note')),
				'link_ev'  => Filter::post('link_ev_note'),
				'link_img' => Filter::post('link_img_note', null, ''),
				'filename' => str_replace([',', ' '], ['_', '_'], HTools::delAccents(Filter::post('filename')) )
			);
		
		//image to upload	
		if ($hsave['filename'] != ''){	
			//resize and upload
			$module = $this->getName();
				$f = classMediaUpload::fnUpload($module, $hsave['filename']);
				if ($f != $hsave['filename'] ) {
					$hsave['filename'] = '';
				}
		}
		session::put('hsave', $hsave);

		$thispage = $_SERVER['PHP_SELF'] ;				
		if(!empty($_SERVER['QUERY_STRING'])){
			$thispage .= '?' . $_SERVER['QUERY_STRING'] ;
		}
		header('Location: ' . $thispage);
		exit;
	}
	
		$controller = new PageController;
		return
			$this->pageHeader($controller) .
			$this->pageBody($controller);
	}

	private function pageHeader(PageController $controller) {
		$fjs =  WT_MODULES_DIR . $this->getName() . '/js/admin.js';
		$msgFieldEmpty = I18N::translate('Fields with a * can not be empty !! ');
		
		$controller
			->restrictAccess(Auth::isAdmin())
			->setPageTitle(I18N::translate('Historical news'))
			->pageHeader()
			->addInlineJavascript('
							function include_css(css_file) {
								var html_doc = document.getElementsByTagName("head")[0];
								var css = document.createElement("link");
								css.setAttribute("rel", "stylesheet");
								css.setAttribute("type", "text/css");
								css.setAttribute("href", css_file);
								html_doc.appendChild(css);
							}
							include_css("' . WT_MODULES_DIR . $this->getName() . '/' . 'css/' . 'config.css'.'");
							var defaultCty = "'. $this->getSetting('JOURNAL_DEFAULT_CTY') . '";
						')
			->addInlineJavascript('var modName =\'' . $this->getName() .'\'
									var msgFieldEmpty = \'' .$msgFieldEmpty . '\' ')
			->addExternalJavascript($fjs)
			;
						
	}

	private function pageBody(PageController $controller) {
	global  $WT_TREE;	
		
		$hist = $this->module()->readHistoFile(); //update file
			
	/* retour de formulaire
	*	input length limited : 64 chars <<<<<<<<<<<<<<<<<<
	*/			
	$len = 254;
	$len64 = 64;
	$hmedia = '';
	$hindex = -1;
	
		$stats = new Stats($WT_TREE);
		$countries = $stats->getAllCountries();
	
	if ($ff = $this->getSetting('JOURNAL_DEFAULT_CTY')){
		$flag = explode(' ', $this->getSetting('JOURNAL_DEFAULT_CTY')); //default -> config
	} else {
		$flag = array('FRA', 'France');
		$this->setSetting('JOURNAL_DEFAULT_CTY', 'FRA France');
	}
		
	//return form

		if  ( ( session::has('hsave') ) ) {
			$hsave = session::get('hsave');
			$htype = $hsave['htype'];
			$hname = $hsave['hname'];
			$hdate = $hsave['hdate'];
			$hname = $hsave['hname'];
			$hindex = $hsave['hindex'];
			$country = $hsave['country'];
			$fdefault = $hsave['fdefault']; //bool checkbox
			$hcomment = $hsave['hcomment'];
			$link_ev = $hsave['link_ev'];
			$link_img = $hsave['link_img'];
			$filename = $hsave['filename'];			
								
			//Vide session		
			session::forget('hsave');
			unset($_FILES);
								
					//Country / flag 
						$keyflag = array_search($country, $countries);	
						$hflag = $keyflag . ' ' . $country;
						//$ct1 =  ' NOTE ' . $country;
						if ($fdefault){
							$this->setSetting('JOURNAL_DEFAULT_CTY', $hflag);
						}
															
				//set gedcom record
				$gedcomhisto = 	'1 EVEN\n2 TYPE ' . $htype .  /* type of event king, president etc... */
										'\n2 DATE ' . $hdate .    /* date of the event */
										'\n2 NOTE ' . $hname .  /* event note: King's name dates etc... */
										'\n2 NOTE ' .$hcomment  .   /* Your own note shown with hover */
										'\n2 NOTE ' . $link_ev .  /* link event (wikipedia...) */
										'\n2 NOTE ' . $hflag . /* Flag country */
										'\n2 NOTE ' . ' ' .$link_img .   /* link image */	
										'\n2 NOTE ' . $filename ;    /* image */	
					
					if ($hindex  == -1 ){	
						$this->module()->insertNewHistoRow($hdate, $gedcomhisto, $hist);
					} else { 
						$hist[$hindex] = $gedcomhisto;
						$this->module()->modifyExistingHistoRow($hist);
					}						
				}
				else {
					$filename='';
					$hindex = -1; // first screen only an example to edit a new recard
					$gedcomhisto = 	'1 EVEN\n2 TYPE ' . ' ' .  /* type of event king, president etc... */
										'\n2 DATE ' . ' ' .    /* date of the event */
										'\n2 NOTE ' . ' ' .  /* event note: King's name dates etc... */
										'\n2 NOTE ' .' '  .   /* Your own note shown with hover */
										'\n2 NOTE ' . ' ' .  /* link event (wikipedia...) */
										'\n2 NOTE ' . $this->getSetting('JOURNAL_DEFAULT_CTY') . /* Flag country */
										'\n2 NOTE ' . ' ' ;  /* link image */	
				$gedcomhisto .=	'\n2 NOTE ' . ' ' .'';   /* image */							
			}
	
		/*************************
		// open page....
		***************************/
				
				$msgFieldEmpty = I18N::translate('Fields with a * can not be empty !! '); 	
				echo $this->getBandeau($controller);
				?>
			
	<div id="selectHNews" title="<?php echo I18N::translate('Choose an event and edit it OR create a new one filling the form below'); ?> ">
		<?php echo $this->module()->selectListHistoFacts($hist); ?>
		
			<div class="form-group">
				<label class="control-label col-sm-4">	</label>
				<div class="col-sm-8">					
					<p class="small text-muted">	</p>
				</div>	
			</div>
	</div>			

	<div class="evviewimg">
		<?php 
			$dir = WT_DATA_DIR . $this->getName() . '/thumbs' ;
			$link = '';
			if (($filename == '') || (!file_exists($dir . '/' . $filename)) ){
				$file = self::DEFAULT_PICTURE;
				$link  = 'http://' . WT_LOCALE . '.wikipedia.org/';
			} else {
				$file = $filename;
				$link = $link_img;
			}
			
			$link1 = '';
			echo '<table id="evmodel"><tr><td class="evimg">' . 
						$this->module()->printImage($file, $dir, $link, $link1) . 
				'</td></tr>'; ?>			
				<tr><td style="border:1px solid black;" id="evtxtmodel">				
				</td></tr></table>
	</div>

	<div id="confHNews">		
			<div class="form-group">
				<label class="control-label col-sm-4">	</label>
				<div class="col-sm-8">
					<?php 		
								echo $this->module()->editHistoFact($gedcomhisto, $hindex);						
					?>
					<p class="small text-muted">	</p>
				</div>	
			</div>
	</div>		
		<?php
	}

	/////////////////// Header ///////////////////

	private function getBandeau($controller){
		$linkdoc = Site::getPreference('MY_VERSIONS_DOC_BASE_URL') . $this->getName() . '.html';
		$linklog = Site::getPreference('MY_VERSIONS_DOC_BASE_URL') . $this->getName() . '_log.txt';
		$linkupd = 'module.php?mod=' . $this->getName() . '&mod_action=check_version';
		
 		//update version?
		myUpdateFunctions::checkNewModsVersions();
		$spref = Site::getPreference('LATEST_MY_MODS_VERSION');
	
		if ($spref !== null){
			$new_version = unserialize($spref)[$this->getName()]['version'];
		} else {		
			$new_version = self::CUSTOM_VERSION;
		}

		$html = '<ol class="breadcrumb small">
			<li><a href="admin.php">'. I18N::translate('Control panel') . '</a></li>
			<li><a href="admin_modules.php">' . I18N::translate('Module administration') . '</a></li>
			<li class="active">' . $controller->getPageTitle() . '</li>
		</ol>';
		$html .= '<div style="
						border:2px solid black;
						border-radius:3px;
						padding:10px;">';
					
		$html .= '	<table style="width:95%;">
			<tr>
			<td style="width:65%; text-align:center;">
			<h3>' . $this->getTitle() . '  V-' . self::CUSTOM_VERSION . '   ' . '<span style="font-size:60%;">(' . 
							self::CUSTOM_VERSION_DATE . ')</span></h3>
			</td>
			<td style="text-align:center;"><span>
				<a href="' . $linkdoc . '">' .  I18N::translate('Documentation') . '
				</a></span></td>
			<td style="text-align:center;"><span>
			<a href="' . $linklog . '">' .  I18N::translate('Change.log') . '
			</a></span></td>
			<td style="text-align:center;" >
			<a href="' . $linkupd . '" title="' . I18N::translate('Checking is done every week, but you can force it now')  . '"><button 
												style="background-color:lightgrey;"
												>' . I18N::translate('Check new version now!') . '</button></a>
			</td>
			</tr>';
			
		$html .= '<tr><td style="text-align:center;" colspan="3">';
		//new version?
		$html .= myUpdateFunctions::lookForNewVersion($this->getName(), self::CUSTOM_VERSION, $new_version ) ;
		$html .= '</td></tr>';
		
		$html .= '</table></div><br>';

	return $html;
	}
	
	
	
	public function forceUpdate(){
		myUpdateFunctions::checkNewModsVersions($now = true);
		header('Location:module.php?mod=' . $this->getName() .'&mod_action=admin_config');
	}	
}
