<?php
/**
 * webtrees: online genealogy
 * Copyright (C) 2016 webtrees development team
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
namespace Andre\WebtreesAddOn\Histo;

/**
 * 
 *
 * 
 */


use Fisharebest\Webtrees\Controller\PageController;
use Fisharebest\Webtrees\Functions\Functions;
use Fisharebest\Webtrees\Functions\FunctionsMedia;
use Fisharebest\Webtrees\Query\QueryMedia;
use Fisharebest\Webtrees\Auth;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Filter;
use Fisharebest\Webtrees\File;
use Fisharebest\Webtrees\FlashMessages;
use Fisharebest\Webtrees\Html;
use Fisharebest\Webtrees\Log;
use Fisharebest\Webtrees\Session;


class classMediaUpload {
	
	public static function fnUpload($module, $filename = ''){	
	global $WT_TREE;

	$MEDIA_DIRECTORY = $module . '/thumbs';
	$imgName = '';
	
	$action = "upload";
		
	if ($action == "upload") {
							
					// Make sure the media folder exists
					if (!is_dir(WT_DATA_DIR . $MEDIA_DIRECTORY)) {
						if (File::mkdir(WT_DATA_DIR . $MEDIA_DIRECTORY)) {
							FlashMessages::addMessage(I18N::translate('The folder %s has been created.', Html::filename(WT_DATA_DIR . $MEDIA_DIRECTORY)));
							Log::addMediaLog('folder created for ' . $MEDIA_DIRECTORY . ' (copy of main image)' . $action);
						} else {
							FlashMessages::addMessage(I18N::translate('The folder %s does not exist, and it could not be created.', Html::filename(WT_DATA_DIR . $MEDIA_DIRECTORY)), 'danger');
							Log::addMediaLog('folder not/already created for ' . $MEDIA_DIRECTORY . ' (copy of main image)' . $action);
							exit();
						}
					}
					
					// User-specified filename?
					// Use the name of the uploaded file?
									
					// Validate the media path and filename			
					if (preg_match('/([\/\\\\<>])/', $filename, $match)) {
						// Local media files cannot contain certain special characters				
						return $filename = '';				
					} elseif (preg_match('/(\.(php|pl|cgi|bash|sh|bat|exe|com|htm|html|shtml))$/i', $filename, $match)) {
						// Do not allow obvious script files.				
						return $filename = '';				
					} 

					// Now copy the file to the correct location.
									
					$ext = (HTools::getExtFile($_FILES['mediafile']['name']));					
					
					if ($filename != ''){ 
						$imgName = explode('.',$filename)[0] .'.' . $ext;
					} else {
						$imgName = $_FILES['mediafile']['name'] ;
					}	
					
					if (( $_FILES['mediafile']['tmp_name'] != '' ) ){	
						$thumb = self::createThumb($module, $_FILES['mediafile']['tmp_name'], $imgName); 
					}		
		} else { 
			$imgName = $filename;
		}
	return $imgName;
	}	

	
	public static function printFormUpload(){
		global $WT_TREE;	

	// Determine file size limit
	$filesize = ini_get('upload_max_filesize');
	if (empty($filesize)) {
		$filesize = "2M";
	}

	$html  = '<tr><th colspan="2">
		<h3>' .
		I18N::translate('Upload media files') . '   ' . 
		I18N::translate('It will be attached to this event') . '</h3>
		</th></tr>';

	$html .= '<tr><th colspan="2">' . I18N::translate('Upload an image file from your local computer. Image will be resized') . '<br>';
	$html .=  '( jpg - jpeg - gif - png ' . I18N::translate('Maximum upload size: ') . $filesize .')';
	$html .= '</th></tr>';
		
	// Print the form
	$html .= '<input type="hidden" name="action" value="upload">';

	// Print form for uploading  an image
	$html .= '<tr><td>' . 
			I18N::translate('Image file') .
			'</td>
			 <td>';
	$html .= '<input name="mediafile" type="file" size="40">' .
			 '</td></tr>' . 
			 '	
			</p>';
		//</form>';
	return $html;			
	}

	/*
	*	now, use getimagesize
	*/
	private static function getMimeType($file){
		$ext = HTools::getExtFile($file);
		switch ($ext){
			case 'jpg':
			case 'JPG':
			case 'jpeg':
			case 'JPEG':
				return 'image/jpg';
			break;	
			case 'png':
			case 'PNG':
				return 'image/png';
			break;
			case 'gif':
			case 'GIF':
				return 'image/gif';
			break;	
			
		}
	}


		/*
		*	param $main_file path
		*	param $file  thumb name
		*/
	private static function createThumb($module, $main_file, $name){
		$THUMBNAIL_WIDTH = 60;
		//thumbnail
		$file = WT_DATA_DIR . $module . '/thumbs/' . $name;
		
		try {
				$imgsize = getimagesize($main_file); 
				// Image small enough to be its own thumbnail?
				if ($imgsize[0] <= $THUMBNAIL_WIDTH && $imgsize[1] <= $THUMBNAIL_WIDTH) {
					try {
						copy($main_file, $file);
						Log::addMediaLog('Thumbnail created for ' . $main_file . ' (copy of main image)' . $file);
					} catch (\ErrorException $ex) {
						Log::addMediaLog('Thumbnail could not be created for ' . $main_file . ' (copy of main image)');
					}
				} else {
					if (FunctionsMedia::hasMemoryForImage($main_file)) {
						try {
							
							switch ($imgsize['mime']) {
							case 'image/png':
								$main_image = imagecreatefrompng($main_file);
								break;
							case 'image/gif':
								$main_image = imagecreatefromgif($main_file);
								break;
							case 'image/jpeg':
							case 'image/jpg':
								$main_image = imagecreatefromjpeg($main_file);
								break;
							default:
								return $file; // Nothing else we can do :-(
							}
							
							if ($main_image) {
								// How big should the thumbnail be?
								$width       = $THUMBNAIL_WIDTH;
								$height = $width;
								
								$imgAspectRatio = $imgsize[0] / $imgsize[1];
								
						if ($imgAspectRatio > 1){
							$height = round($THUMBNAIL_WIDTH / $imgAspectRatio);
						} elseif ($imgAspectRatio < 1) {	
							$width = round($THUMBNAIL_WIDTH * $imgAspectRatio);
						} 
						
								$thumb_image = imagecreatetruecolor($width, $height);
									
								// Create a transparent background, instead of the default black one
								imagesavealpha($thumb_image, true);
								imagefill($thumb_image, 0, 0, imagecolorallocatealpha($thumb_image, 0, 0, 0, 127));
								// Shrink the image
								imagecopyresampled($thumb_image, $main_image, 0, 0, 0, 0, $width, $height, $imgsize[0], $imgsize[1]);
								
								switch ($imgsize['mime']) {
								case 'image/png':
									imagepng($thumb_image, $file);
									break;
								case 'image/gif':
									imagegif($thumb_image, $file);
									break;
								case 'image/jpeg':
								case 'image/jpg':
									imagejpeg($thumb_image, $file);
									break;
								}
								imagedestroy($main_image);
								imagedestroy($thumb_image);
								Log::addMediaLog('Thumbnail created for ' . $main_file);
							}
						} catch (\ErrorException $ex) {
							Log::addMediaLog('Failed to create thumbnail for ' . $main_file . ' (' . $ex . ')');
						}
					} else {
						Log::addMediaLog('Not enough memory to create thumbnail for ' . $main_file . '/' . $file );
					}
				}
			} catch (\ErrorException $ex) {
				// Not an image, or not a valid image?
			}
	return true;
	}

	
}
