<?php
// Classes and libraries for module system
//
// webtrees: Web based Family History software
// Copyright (C) 2012 webtrees development team.
//
// Derived from PhpGedView
// Copyright (C) 2010 John Finlay
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//-----------------------------------------------------------------------------------------------------
//Andre DUMAS Aug 2012 for Webtrees V1.4.0 and +
//V 1.0.1
// $Id: module.php 15000 2013-03-26 22:28:50Z andre V1.0.0 FR $
//V1.1 Prefer  pdf files than blocks with html codes but the two ways are still working (see readme.txt
//V-1.5.1 Rev December 2013 for Webtrees V-1.5.1 and +
//-----------------------------------------------------------------------------------------------------

/*
*    FNS family_namestories  V-1-7-2  beta  for Webtrees 1.7.2
*    André DUMaS Sptember 2015
*    pdf saved in media/Patronymes/
*    
*    TODO: next step, very soon: associate pdf xith sources, so we'll integrate pdf in WT 
*    so thhis is a transition version
*	=.=.=.=.=.=.=.=..=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=
*	FNS New name FamilyNameStories V-1-7-4-1
*		for Webtrees 1.7.4
*		André DUMAS 10-06-2016
*	http://www.adumas.1s.fr/wt
*	http://www.adumas.1s.fr/download
*  
*	FNS V-1-7-4-2    16-JUN-2016
*	add note/media/text from information page for admin/editor  
*/
namespace Andre\WebtreesAddOn\Histo;

use Composer\Autoload\ClassLoader;
use Fisharebest\Webtrees\Controller\BaseController;
use Fisharebest\Webtrees\Controller\PageController;
use Fisharebest\Webtrees\Controller\SourceController;
use Fisharebest\Webtrees\GedcomRecord;
use Fisharebest\Webtrees\Filter;
use Fisharebest\Webtrees\Source;
use Fisharebest\Webtrees\File;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Log;
use Fisharebest\Webtrees\Note;
use Fisharebest\Webtrees\Media;
use Fisharebest\Webtrees\Module;
use Fisharebest\Webtrees\Module\AbstractModule;

use Fisharebest\Webtrees\Module\ModuleSidebarInterface;
use Fisharebest\Webtrees\Module\ModuleConfigInterface;

use Fisharebest\Webtrees\Individual;
use Fisharebest\Webtrees\Menu;
use Fisharebest\Webtrees\Auth;
use Fisharebest\Webtrees\PDO;
use Fisharebest\Webtrees\Database;
use Fisharebest\Webtrees\Functions\Functions;
use Fisharebest\Webtrees\GedcomTag;
use Fisharebest\Webtrees\Functions\FunctionsPrint;
use Fisharebest\Webtrees\Functions\FunctionsEdit;
use Fisharebest\Webtrees\Module\CkeditorModule;


use Andre\WebtreesAddOn\Histo\Template\AdminTemplate;


class histoModule extends AbstractModule implements ModuleSidebarInterface, ModuleConfigInterface {
            
		CONST CUSTOM_VERSION = '1-7-9-6a';
		CONST CUSTOM_VERSION_DATE = '27-04-2018';
		CONST CUSTOM_VERSION_AUTHOR = 'André DUMAS FRANCE';
		const CUSTOM_WEBSITE  = 'http://www.adumas.1s.fr/wt';
		
		const SCHEMA_TARGET_VERSION			= 1;
		const SCHEMA_SETTING_NAME			= 'JOURNAL_SCHEMA_VERSION';
		const SCHEMA_MIGRATION_PREFIX		= '\Andre\WebtreesAddOn\Histo\Schema';
	
		
		const  DEFAULT_PICTURE = 'cesar.jpg'; 
		var $dir_jmedia;
		
		var $headers; // CSS and script to include in the top of <head> section, before theme’s CSS
		var $js; // the journalHandler javascript
		var $css;
		
		public $facts;
		
			
 	public function __construct() {
		parent::__construct(__DIR__);

		$this->directory = WT_MODULES_DIR . $this->getName();
		
		// register the namespaces
		$loader = new ClassLoader();
		$loader->addPsr4('Andre\\WebtreesAddOn\\Histo\\', $this->directory . '/app');
		$loader->register();
		
		$this->dir_jmedia = WT_DATA_DIR . $this->getName() . '/thumbs/'; 
		
	}
	
	/**
	 * Get the module class.
	 * JustCarmen Thanks (-_+)
	 * Class functions are called with $this inside the source directory.
	 */
	protected function module() {
		return new HTools;
	}
	
	protected function template() {
		return new AdminTemplate;
	}

	// Extend class Module
	public function getTitle() {	
	return  /* I18N: Name of a module*/  I18N::translate('Historical informations');	
}

	// Extend class Module
	public function getDescription() {
		return /* I18N: Description of the "Family names stories" module */ I18N::translate('AHisto');
	}
	
// Extend class Module
	public function defaultAccessLevel() {
		return Auth::PRIV_PRIVATE;
		}
	///
	
	// Implement Module_Sidebar
	public function defaultSidebarOrder() {
		return 1;
	}

	// Implement Module_Sidebar
	public function hasSidebarContent() {		
		return true;
	}


	// Implement Module_Sidebar
	public function getSidebarAjaxContent() {
		return '';
	}

	
	//
	//content of he sidebar AD 2012
	public function getSidebarContent() {
		global $controller, $show_full, $edit, $GEDCOM, $WT_TREE, $pid;
		$show_full="1";
		$out = '';	
		$js = WT_STATIC_URL . WT_MODULES_DIR. $this->getName() . '/js/histo.js';
		$controller->addInlineJavascript('
										')
					->addInlineJavascript('
							function include_css(css_file) {
								var html_doc = document.getElementsByTagName("head")[0];
								var css = document.createElement("link");
								css.setAttribute("rel", "stylesheet");
								css.setAttribute("type", "text/css");
								css.setAttribute("href", css_file);
								html_doc.appendChild(css);
							}
							include_css("' . WT_MODULES_DIR . $this->getName() . '/' . 'css/' . 'histo.css' .'");
							
						')
						->addExternalJavascript($js)
		;
		
		
			// =====================================================================
	
			//for deskTab and update
				if (!$this->getSetting('CUSTOM_VERSION')  || ( $this->getSetting('CUSTOM_VERSION') != self::CUSTOM_VERSION )  ){
					$this->setSetting('CUSTOM_VERSION', self::CUSTOM_VERSION);
				}
		
		if (!is_dir($this->dir_jmedia)){
			File::mkdir($this->dir_jmedia);
			$this->moveDefaultPicture();
		} else {
			if (!file_exists($this->dir_jmedia . self::DEFAULT_PICTURE)){$this->moveDefaultPicture();}
		}
		
		$this->setSecurity(WT_DATA_DIR . $this->getName() );
		
		$histo = $this->module()->readHistoFile();
		
		$files = scandir($this->dir_jmedia); /* use in_array in foreach */
		$person = Individual::getInstance($pid, $WT_TREE);
		$this->facts = HTools::historicalFacts($person);
		
		$jtext = '<div><ul>
					<li class="fjournal"><p>' . I18N::translate('What happened  during this life...'). '</p></li>';
		$comment = '';		
		$jimages = '<div>' .$this->module()->printThumbnail(self::DEFAULT_PICTURE) . '</div>';
		$ctext = count($this->facts);
		$photo = '';  /* titre de la photo, appellée par ajax $fact->getNotes()[1] ; photo pourrait être un tableau avec les params de l'image */
		if ($this->getSetting('JOURNAL_DEFAULT_CTY')){
			$flag = explode(' ', $this->getSetting('JOURNAL_DEFAULT_CTY')); //default -> config
		} else {
			$flag = array('FRA', 'France');
		}
		/*
		*  	new version : count($fnotes) = 6
		*	fHnews org  count = 2 only add image
		*  	org webtrees version count =1 no image
		*	image = $fnotes[count -1)
		*/
		$fnotes = array();
		$link_img = '';
		$link_ev = '';
		$i = 0;
		
		foreach ($this->facts as $fact){
			$fnotes = $fact->getNotes();  
			$cp_notes = count($fnotes);  
			switch  ($cp_notes) {
				case '1':					
					$fnotes = array($fnotes[0], '', '', $this->getSetting('JOURNAL_DEFAULT_CTY'), '', '');
					$cp_notes = 6;
				break;
				case '2':
					$fnotes = array($fnotes[0], '', '', $this->getSetting('JOURNAL_DEFAULT_CTY'), '', $fnotes[1]);
					$cp_notes = 6;
				break;
				default:
					$cp_notes = 6;
				break;
			}
						
			if ($cp_notes > 0) {
								$comment = $fnotes[1]; 
								$link_ev = $fnotes[2];
								$flag = explode(' ',$fnotes[3]);
								$link_img = $fnotes[4];
								if (count($flag) < 2){
									$flag = array('FRA', 'France'); //default 
								}
				}
			
				$jtext .= '<li class="fjournal" rel="' . $link_ev . '">'.
					'<div class="flag s' . $i  . '" flag="' .
					   WT_MODULES_DIR .$this->getName() .'/images/flags/' . $flag[0] . '">
					   ' . $flag[1] . ' 
					   ' . '</div>' .
					'<div class="s' . $i  . '">' . ' &nbsp  &nbsp ' . $fact->getDate()->display() . ' &nbsp  &nbsp ' . '</div>
					<div>' . 
					$fact->getLabel()  . '</div><div>' . 
					$fnotes[0] . 
					'</div>
					<div class="photo" style="display:none;">' . 
					$photo . 
					'</div>
					<div><span class="comment  s' . $i . '" style="display:none;width:50px;height:50px;">' . $comment .'</span></div></li>';	
					

			if (($cp_notes > 1 ) ){
				if ( ($fnotes[$cp_notes  - 1] != null) && (in_array($fnotes[$cp_notes  - 1], $files)) ){
					$jimages .= '<div>' . $this->module()->printThumbnail($fnotes[$cp_notes  - 1] , $link_img) . '</div>';
				} else {
				$jimages .= '<div></div>';
				}
			} else {
				$jimages .= '<div></div>';
			}
		$i++;	
		}
		$jtext .= '</ul></div>';
		
		$text = '<div><p>' . I18N::translate('What happened  during this life...'). '</p></div>';
		
		$tableauIn = '<table id="tableNews">' .					
					'<tr>';
					
		$tableauOut = '</tr></table>' ;
		
		$jimage = $this->module()->printThumbnail(self::DEFAULT_PICTURE);
	
		$js = '
				var pid =  "'.Filter::get("pid").'";'.'
				var ctext = "' . $ctext .'";'.'
				var path = \'module.php?mod='.$this->getName() . '&mod_action=\';' . '
				var visu = \' ' . $tableauIn . ' <td class="jimage" rel="' . $link_img . 
				'"><div class="scrollImage">' . $jimage . '</div></td><td class="jtext" rel="' . 
				$link_ev . '"><div class="scrollText">' . $text . '</div></td> ' . $tableauOut . ' \';				
				$("h3#journal").append(visu); 
		';
	
		$controller 
					->addInlineJavaScript($js, BaseController::JS_PRIORITY_LOW);
					
				
					$out = '<div id="jNews" style="display:none;">' . $jtext . '</div>
							<div id="jPhotos" style="display:none;">' . $jimages . '</div>';
				
		return $out;

	} // End public function getTabContentSB()
		
	///
	// Extend Module
	public function modAction($mod_action) {
		global $WT_TREE;
		switch ($mod_action) {
			case 'admin_config':
					$this->config();
			break;
			
			case 'check_version':
				$this->template()->forceUpdate();
			break;
			case 'edit_hevent' :
			   $hevent = Filter::postInteger('hev');
			   $histo = HTools::readHistoFile();
			   //envoyer &$hevent avec pour la modification
			   echo $histo[(int)$hevent];
			break;
			case 'thumbnail':
				$file			= Filter::get('file');
				$filename	 	= $this->module()->myDir() . 'thumbs/' . $file;	
				$mimetype 		= HTools::getMimeType($file);
				$filetime		= filemtime($filename);
				$filetimeHeader	= gmdate('D, d M Y H:i:s', $filetime) . ' GMT';
				$expireOffset	= 3600 * 24 * 7; // tell browser to cache this image for 7 days
				$expireHeader	= gmdate('D, d M Y H:i:s', WT_TIMESTAMP + $expireOffset) . ' GMT';
				$etag			=  trim(md5_file($filename), '"\'');
				$filesize		= filesize($filename);

				// parse IF_MODIFIED_SINCE header from client
				$if_modified_since = 'x';
				if (isset($_SERVER['HTTP_IF_MODIFIED_SINCE'])) {
					$if_modified_since = preg_replace('/;.*$/', '', $_SERVER['HTTP_IF_MODIFIED_SINCE']);
				}

				// parse IF_NONE_MATCH header from client
				$if_none_match = 'x';
				if (isset($_SERVER['HTTP_IF_NONE_MATCH'])) {
					$if_none_match = str_replace('"', '', $_SERVER['HTTP_IF_NONE_MATCH']);
				}

				// add caching headers.  allow browser to cache file, but not proxy
				header('Last-Modified: ' . $filetimeHeader);
				header('ETag: "' . $etag . '"');
				header('Expires: ' . $expireHeader);
				header('Cache-Control: max-age=' . $expireOffset . ', s-maxage=0, proxy-revalidate');

				// if this file is already in the user’s cache, don’t resend it
				// first check if the if_modified_since param matches
				if ($if_modified_since === $filetimeHeader) {
					// then check if the etag matches
					if ($if_none_match === $etag) {
						http_response_code(304);
						return;
					}
				}

				// send headers for the image
				header('Content-Type: ' . $mimetype);
				header('Content-Disposition: filename="' . basename($filename) . '"');
				header('Content-Length: ' . $filesize);

				if (function_exists('readfile')) {
					readfile($filename);
				} else {
					$fp = fopen($filename, 'rb');
					if (function_exists('fpassthru')) {
						fpassthru($fp);
					} else {
						while (!feof($fp)) {
							echo fread($fp, 65536);
						}
					}
					fclose($fp);
				}
				break;
				
				case 'setImage':
					$file = Filter::post('file', null, 'cesar.png');
					$link = Filter::post('link', null, 'http://fr.wikipedia.org/wiki/Jules_C%C3%A9sar');
		
					if (($file == '') && (WT_LOCALE == 'fr') ) {
						$file = 'cesar.png';
						$link = Filter::post('link', null, 'http://fr.wikipedia.org/wiki/Jules_C%C3%A9sar');
					} elseif (($file == '') && (WT_LOCALE != 'fr') ) {
						$file = 'cesar.png';
						$link = 'http://' . WT_LOCALE . '.wikipedia.org/wiki/Jules_C%C3%A9sar';
					} else {						
						$link = 'http://' . WT_LOCALE . '.wikipedia.org/';
					}
						
					$dir = WT_DATA_DIR . $this->getName() . '/thumbs' ;
					echo $this->module()->printImage($file, $dir, $link);
				break;
				case 'savehistoev':

			default:
				echo ('Unknown option');
				exit();
			break;
		}
	}

	
	// Implement Module_Config
	public function getConfigLink() {
		return 'module.php?mod='.$this->getName().'&amp;mod_action=admin_config';
	}

	private function sortFacts($fact){			
	$note ='';
	
	//object or note?
		if ( count($a = explode('@',$fact->getValue() ) )  > 1){
			$note = Note::getInstance($a[1], $fact->getParent()->getTree())->getNote();
		} else {
			$note = $fact->getValue();
		}
		//Show
			$html = '
				<textarea name="fact[]" dir="ltr" rows="'. preg_match_all('/\n/', $fact->getGedcom(), $dummy_parameter_for_php53).
					'" style="width:100%;">'.
						Filter::escapeHtml($note).'
				</textarea>
			';
		return $html;	
	}
	
	


	// Action from the configuration page


	private function config() {
				/* update schema */
				Database::updateSchema(self::SCHEMA_MIGRATION_PREFIX, self::SCHEMA_SETTING_NAME, self::SCHEMA_TARGET_VERSION);
	
				//for deskTab and update
				if (!$this->getSetting('CUSTOM_VERSION')  || ( $this->getSetting('CUSTOM_VERSION') != self::CUSTOM_VERSION )  ){
					$this->setSetting('CUSTOM_VERSION', self::CUSTOM_VERSION);
				}
			$this->template()->pageContent();

	}
	
		/*
	*  const DEFAULT_PICTURE is moved from module/../imagess
	*	to data/journal/thumbs/...
	*/
	private function moveDefaultPicture(){
		$source = WT_MODULES_DIR . $this->getNAme() . '/images/' . self::DEFAULT_PICTURE;
			copy($source, $this->dir_jmedia . self::DEFAULT_PICTURE);
	}
	
		/*	for subdirs in /data/ 
	*	put in each dir an index.php
	*	sending the visitor in the parent dir
	*   param   $jdir  root dir and explore subdirs and search index.php
	*/
	private function setSecurity($jdir){
		$safe = $jdir . '/index.php';
		$text = '<?php
					header("Location: ../index.php");
					exit;
					?>
				';
		//root dir
		if (!file_exists($safe)){
			$handle = fopen($safe, 'w+');
			fwrite($handle, $text);
			fclose($handle);
			
		}	
		//subdirs
		$dirs = scandir($jdir);
		foreach ($dirs as $dir){
			$d = $jdir . '/' . $dir;
			if (is_dir($d )){
				if (!file_exists($d . '/index.php')){
					$handle = fopen($d . '/index.php', 'w+');
					fwrite($handle, $text);
					fclose($handle);
				}	
			}
		}
	return true;	
	}

	
} return new histoModule;
